version 11.1
clear all
capture log close
set more off
set mem 500m

use "final_import_dataset.dta", clear

/* Creating the dependent variable */
gen share_intrafirm= REL_VAL/(REL_VAL+NON_VAL)

/* Creating industry variables #1 */
gen i_capital=ln(total_capital/wages_employees)
for @ in any buildings materials machinery auto_machinery other_machinery: gen i_@=ln(@/wages_employees)
gen i_comp_machinery=ln(computer_machinery/wages_employees)
gen i_skill=ln((wages_employees-wages_production_workers)/(wages_employees))
gen i_RandD=ln(.000001+randd_intensity)
gen i_non_specific_mach=ln((auto_machinery+computer_machinery)/wages_employees)
gen i_non_specific_capital=ln((total_capital-other_machinery)/wages_employees)	/* buildings+auto_machinery+computer_machinery */
gen i_non_specific_capital2=ln((buildings+auto_machinery+computer_machinery)/wages_employees)

log using Antras_2003_imports.log, replace

**********************************
*** Regressions: Antras (2003) ***
**********************************

*******************************
*** TABLE 1: at NAICS level ***
******************************
preserve
collapse (sum) REL_VAL NON_VAL (median) i_capital i_RandD i_skill i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_material i_non_specific_mach i_non_specific_capital, by(io1997)
gen share_intrafirm= REL_VAL/(REL_VAL+NON_VAL)

* Col 1
reg share_intrafirm i_RandD i_skill i_material i_capital, beta
outreg2 using "Table1.xls", replace nocons aster dec(3) stats (beta tstat)		/* Note: Beta coefficients an t-statistics report in output file */
* Col 2
reg share_intrafirm i_RandD i_skill i_material i_buildings i_machinery, beta
outreg2 using "Table1.xls", append nocons aster dec(3) stats (beta tstat)
* Col 3
reg share_intrafirm i_RandD i_skill i_material i_other_machinery i_auto_machinery i_comp_machinery i_buildings, beta
outreg2 using "Table1.xls", append nocons aster dec(3) stats (beta tstat)
* Col 4
reg share_intrafirm i_RandD i_skill i_material i_other_machinery i_non_specific_mach i_buildings, beta
outreg2 using "Table1.xls", append nocons aster dec(3) stats (beta tstat)
* Col 5
reg share_intrafirm i_RandD i_skill i_material i_other_machinery i_non_specific_capital, beta
outreg2 using "Table1.xls", append nocons aster dec(3) stats (beta tstat)
restore

******************************************
*** TABLE 2: HS6 Level & Country Level ***
******************************************
* Col 1
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital i.isocode, cluster(io1997)
outreg2 using "Table2_tstats.xls", replace keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (tstat)			/* File with t-statsics (based on clustered SEs) */
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital i.isocode, beta
outreg2 using "Table2_betas.xls", replace keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (beta)				/* File with beta coefficients */

* Col 2
xi: reg share_intrafirm i_RandD i_skill i_materials i_buildings i_machinery i_RandD i_skill i_material i.isocode, cluster(io1997)
outreg2 using "Table2_tstats.xls", append keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_buildings i_machinery i.isocode, beta
outreg2 using "Table2_betas.xls", append keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (beta)

* Col 3
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_auto_machinery i_comp_machinery i_buildings i.isocode, cluster(io1997)
outreg2 using "Table2_tstats.xls", append keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_auto_machinery i_comp_machinery i_buildings i.isocode, beta
outreg2 using "Table2_betas.xls", append keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (beta)

* Col 4
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_mach i_buildings i.isocode, cluster(io1997)
outreg2 using "Table2_tstats.xls", append keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_mach i_buildings i.isocode, beta
outreg2 using "Table2_betas.xls", append keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (beta)

* Col 5
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_capital i.isocode, cluster(io1997)
outreg2 using "Table2_tstats.xls", keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_capital i.isocode, beta
outreg2 using "Table2_betas.xls", keep(i_RandD i_skill i_materials i_capital i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)

*********************************
*** TABLE 3: Mu specification ***
*********************************
preserve
/* Antras and Helpman (2008) variables */
gen mu=(buildings+auto_machinery+computer_machinery)/(total_capital)
gen mu2=(buildings)/(total_capital)
replace mu=. if mu==0	/* These are missings not zeros */
replace mu2=. if mu2==0

* Column 1
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital mu i.isocode, cluster(io1997)
outreg2 using "Table3_tstats.xls", replace keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (tstat)			/* File with t-statsics (based on clustered SEs) */
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital mu i.isocode, beta
outreg2 using "Table3_betas.xls", replace keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (beta)				/* File with beta coefficients */

* Column 2
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital mu2 i.isocode, cluster(io1997)
outreg2 using "Table3_tstats.xls", keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)				/* File with t-statsics (based on clustered SEs) */
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital mu2 i.isocode, beta
outreg2 using "Table3_betas.xls", keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)				/* File with beta coefficients */

collapse (sum) REL_VAL NON_VAL (median) mu mu2 i_capital i_RandD i_skill  i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital, by(io1997)
gen share_intrafirm= REL_VAL/(REL_VAL+NON_VAL)

* Column 3
reg share_intrafirm i_RandD i_skill i_materials i_capital mu, beta
outreg2 using "Table3_tstats.xls", keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)				/* File with t-statsics (based on clustered SEs) */
outreg2 using "Table3_betas.xls", keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)				/* File with beta coefficients */

* Column 4
reg share_intrafirm i_RandD i_skill i_materials i_capital mu2, beta
outreg2 using "Table3_tstats.xls", keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)				/* File with t-statsics (based on clustered SEs) */
outreg2 using "Table3_betas.xls", keep(mu mu2 i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)				/* File with beta coefficients */
restore

*********************************************
*** TABLE 5: Dropping Non-US Headquarters ***
*********************************************
preserve
for @ in any ISL ITA FIN LIE CHE: drop if isocode=="@"
* Col 1
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital i.isocode, cluster(io1997)
outreg2 using "Table5_tstats.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) replace nocons aster dec(3) stats (tstat)			/* File with t-statsics (based on clustered SEs) */
xi: reg share_intrafirm i_RandD i_skill i_materials i_capital i.isocode, beta
outreg2 using "Table5_betas.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) replace nocons aster dec(3) stats (beta)				/* File with beta coefficients */

* Col 2
xi: reg share_intrafirm i_RandD i_skill i_materials i_buildings i_machinery i_RandD i_skill i_material i.isocode, cluster(io1997)
outreg2 using "Table5_tstats.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_buildings i_machinery i.isocode, beta
outreg2 using "Table5_betas.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)

* Col 3
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_auto_machinery i_comp_machinery i_buildings i.isocode, cluster(io1997)
outreg2 using "Table5_tstats.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_auto_machinery i_comp_machinery i_buildings i.isocode, beta
outreg2 using "Table5_betas.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)

* Col 4
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_mach i_buildings i.isocode, cluster(io1997)
outreg2 using "Table5_tstats.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_mach i_buildings i.isocode, beta
outreg2 using "Table5_betas.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)

* Col 5
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_capital i.isocode, cluster(io1997)
outreg2 using "Table5_tstats.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_materials i_other_machinery i_non_specific_capital i.isocode, beta
outreg2 using "Table5_betas.xls", keep(i_capital i_RandD i_skill i_materials i_machinery i_other_machinery i_auto_machinery i_comp_machinery i_buildings i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)
restore

log close



