clear all
version 11.1
set more off
capture log close
set mem 600m

use "final_import_dataset.dta", clear

drop if missing(foreign_dispersion)==1

/* Depedent variable */
gen share_intrafirm = REL_VAL/(REL_VAL+NON_VAL)

/* Creating industry variables */
gen i_capital=ln(total_capital/wages_employees)
for @ in any buildings materials machinery auto_machinery other_machinery: gen i_@=ln(@/wages_employees)
gen i_comp_machinery=ln(computer_machinery/wages_employees)
gen i_skill=ln((wages_employees-wages_production_workers)/(wages_employees))
gen i_RandD=ln(.000001+randd_intensity)
gen i_non_specific_mach=ln((auto_machinery+computer_machinery)/wages_employees)
gen i_non_specific_capital=ln((total_capital-other_machinery)/wages_employees)	/* buildings+auto_machinery+computer_machinery */
gen i_non_specific_capital2=ln((buildings+auto_machinery+computer_machinery)/wages_employees)

drop wages_employees wages_production_workers value_added materials value_shipments total_capital buildings machinery auto_machinery computer_machinery other_machinery

log using Antras_Helpman_2004_imports.log, replace

****************************************
*** TABLE 7: Interaction regressions ***
****************************************

/* Creating interactions */
for @ in any materials RandD capital machinery buildings other_machinery auto_machinery comp_machinery skill non_specific_capital: gen f_dispers_x_@=foreign_dispersion*i_@

********************************
** Col 1: Headquarter=Capital **
********************************
xi: areg share_intrafirm foreign_dispersion f_dispers_x_capital i_capital i_skill i_RandD i_materials, absorb(isocode) cluster(io1997) 
outreg2 using "Table7.xls", replace keep(foreign_dispersion f_dispers_x_capital) nocons aster dec(3)

**********************************
** Col 2: Headquarter=Machinery **
**********************************
xi: areg share_intrafirm foreign_dispersion f_dispers_x_machinery i_machinery i_buildings i_skill i_RandD i_materials, absorb(isocode) cluster(io1997) 
outreg2 using "Table7.xls", append keep(foreign_dispersion f_dispers_x_machinery) nocons aster dec(3)
 
****************************************
** Col 3: Headquarter=Other Machinery **
****************************************
xi: areg share_intrafirm foreign_dispersion f_dispers_x_other_machinery i_other_machinery i_skill i_RandD i_non_specific_capital i_materials, absorb(isocode) cluster(io1997) 
outreg2 using "Table7.xls", append keep(foreign_dispersion f_dispers_x_other_machinery) nocons aster dec(3)

******************************
** Col 4: Headquarter=Skill **
******************************
xi: areg share_intrafirm foreign_dispersion f_dispers_x_skill i_capital i_skill i_RandD i_materials, absorb(isocode) cluster(io1997) 
outreg2 using "Table7.xls", append keep(foreign_dispersion f_dispers_x_skill) nocons aster dec(3)

****************************
** Col 5: Headquarter=R&D **
****************************
xi: areg share_intrafirm foreign_dispersion f_dispers_x_RandD i_capital i_skill i_RandD i_materials, absorb(isocode) cluster(io1997) 
outreg2 using "Table7.xls", append keep(foreign_dispersion f_dispers_x_RandD) nocons aster dec(3)

for @ in any materials RandD capital machinery buildings other_machinery auto_machinery comp_machinery skill: drop f_dispers_x_@


***********************************
*** TABLE 8: Decile regressions ***
***********************************

/* Constructing dispersion decile variables */
/* Non-parametric - capital intensity */
egen group_capital=cut(i_capital), group(10)
for # in num 0/9: gen capital#=0
for # in num 0/9: replace capital#=1 if group_capital==#
for # in num 0/9: gen f_dispersion_x_capital#=foreign_dispersion*capital#
/* Non-parametric - machinery intensity */
egen group_machinery=cut(i_machinery), group(10)
for # in num 0/9: gen machinery#=0
for # in num 0/9: replace machinery#=1 if group_machinery==#
for # in num 0/9: gen f_dispersion_x_machinery#=foreign_dispersion*machinery#
/* Non-parametric - other machinery intensity */
egen group_other_machinery=cut(i_other_machinery), group(10)
for # in num 0/9: gen other_machinery#=0
for # in num 0/9: replace other_machinery#=1 if group_other_machinery==#
for # in num 0/9: gen f_dispersion_x_other_machinery#=foreign_dispersion*other_machinery#

********************************
** Col 1: Headquarter=Capital **
********************************
xi: areg share_intrafirm f_dispersion_x_capital0-f_dispersion_x_capital9 capital* i_capital i_skill i_RandD i_material, absorb(isocode) cluster(io1997) 
outreg2 using "Table8.xls", replace keep(f_dispersion_x_capital0 f_dispersion_x_capital1 f_dispersion_x_capital2 f_dispersion_x_capital3 f_dispersion_x_capital4 f_dispersion_x_capital5 f_dispersion_x_capital6 f_dispersion_x_capital7 f_dispersion_x_capital8 f_dispersion_x_capital9) nocons aster dec(3)

**********************************
** Col 2: Headquarter=Machinery **
**********************************
xi: areg share_intrafirm f_dispersion_x_machinery0-f_dispersion_x_machinery9 machinery* i_machinery i_buildings i_skill i_RandD i_material, absorb(isocode) cluster(io1997) 
outreg2 using "Table8.xls", append keep(f_dispersion_x_machinery0 f_dispersion_x_machinery1 f_dispersion_x_machinery2 f_dispersion_x_machinery3 f_dispersion_x_machinery4 f_dispersion_x_machinery5 f_dispersion_x_machinery6 f_dispersion_x_machinery7 f_dispersion_x_machinery8 f_dispersion_x_machinery9) nocons aster dec(3)

****************************************
** Col 3: Headquarter=Other Machinery **
****************************************
xi: areg share_intrafirm f_dispersion_x_other_machinery0-f_dispersion_x_other_machinery9 other_machinery* i_other_machinery i_non_specific_capital i_skill i_RandD i_material, absorb(isocode) cluster(io1997) 
outreg2 using "Table8.xls", append keep(f_dispersion_x_other_machinery0 f_dispersion_x_other_machinery1 f_dispersion_x_other_machinery2 f_dispersion_x_other_machinery3 f_dispersion_x_other_machinery4 f_dispersion_x_other_machinery5 f_dispersion_x_other_machinery6 f_dispersion_x_other_machinery7 f_dispersion_x_other_machinery8 f_dispersion_x_other_machinery9) nocons aster dec(3)

log close
